==> d3-color-0.3.4.tgz: package/src/cubehelix.js <==
import {Color, rgb, Rgb, darker, brighter} from "./color";
import {deg2rad, rad2deg} from "./math";

var A = -0.14861,
    B = +1.78277,
    C = -0.29227,
    D = -0.90649,
    E = +1.97294,
    ED = E * D,
    EB = E * B,
    BC_DA = B * C - D * A;

export default function cubehelix(h, s, l) {
  if (arguments.length === 1) {
    if (h instanceof Cubehelix) {
      l = h.l;
      s = h.s;
      h = h.h;
    } else {
      if (!(h instanceof Rgb)) h = rgb(h);
      var r = h.r / 255, g = h.g / 255, b = h.b / 255;
      l = (BC_DA * b + ED * r - EB * g) / (BC_DA + ED - EB);
      var bl = b - l, k = (E * (g - l) - C * bl) / D;
      s = Math.sqrt(k * k + bl * bl) / (E * l * (1 - l)); // NaN if l=0 or l=1
      h = s ? Math.atan2(k, bl) * rad2deg - 120 : NaN;
      if (h < 0) h += 360;
    }
  }
  return new Cubehelix(h, s, l);
}

export function Cubehelix(h, s, l) {
  this.h = +h;
  this.s = +s;
  this.l = +l;
}

var _cubehelix = cubehelix.prototype = Cubehelix.prototype = new Color;

_cubehelix.brighter = function(k) {
  k = k == null ? brighter : Math.pow(brighter, k);
  return new Cubehelix(this.h, this.s, this.l * k);
};

_cubehelix.darker = function(k) {
  k = k == null ? darker : Math.pow(darker, k);
  return new Cubehelix(this.h, this.s, this.l * k);
};

_cubehelix.rgb = function() {
  var h = isNaN(this.h) ? 0 : (this.h + 120) * deg2rad,
      l = +this.l,
      a = isNaN(this.s) ? 0 : this.s * l * (1 - l),
      cosh = Math.cos(h),
      sinh = Math.sin(h);
  return new Rgb(
    255 * (l + a * (A * cosh + B * sinh)),
    255 * (l + a * (C * cosh + D * sinh)),
    255 * (l + a * (E * cosh))
  );
};

==> d3-color-0.4.0.tgz: package/src/cubehelix.js <==
import {Color, rgb, Rgb, darker, brighter} from "./color";
import {deg2rad, rad2deg} from "./math";

var A = -0.14861,
    B = +1.78277,
    C = -0.29227,
    D = -0.90649,
    E = +1.97294,
    ED = E * D,
    EB = E * B,
    BC_DA = B * C - D * A;

export default function cubehelix(h, s, l, opacity) {
  if (arguments.length === 1) {
    if (h instanceof Cubehelix) {
      opacity = h.opacity;
      l = h.l;
      s = h.s;
      h = h.h;
    } else {
      if (!(h instanceof Rgb)) h = rgb(h);
      opacity = h.opacity;
      var r = h.r / 255, g = h.g / 255, b = h.b / 255;
      l = (BC_DA * b + ED * r - EB * g) / (BC_DA + ED - EB);
      var bl = b - l, k = (E * (g - l) - C * bl) / D;
      s = Math.sqrt(k * k + bl * bl) / (E * l * (1 - l)); // NaN if l=0 or l=1
      h = s ? Math.atan2(k, bl) * rad2deg - 120 : NaN;
      if (h < 0) h += 360;
    }
  }
  return new Cubehelix(h, s, l, opacity);
}

export function Cubehelix(h, s, l, opacity) {
  this.h = +h;
  this.s = +s;
  this.l = +l;
  this.opacity = opacity == null ? 1 : +opacity;
}

var _cubehelix = cubehelix.prototype = Cubehelix.prototype = new Color;

_cubehelix.brighter = function(k) {
  k = k == null ? brighter : Math.pow(brighter, k);
  return new Cubehelix(this.h, this.s, this.l * k, this.opacity);
};

_cubehelix.darker = function(k) {
  k = k == null ? darker : Math.pow(darker, k);
  return new Cubehelix(this.h, this.s, this.l * k, this.opacity);
};

_cubehelix.rgb = function() {
  var h = isNaN(this.h) ? 0 : (this.h + 120) * deg2rad,
      l = +this.l,
      a = isNaN(this.s) ? 0 : this.s * l * (1 - l),
      cosh = Math.cos(h),
      sinh = Math.sin(h);
  return new Rgb(
    255 * (l + a * (A * cosh + B * sinh)),
    255 * (l + a * (C * cosh + D * sinh)),
    255 * (l + a * (E * cosh)),
    this.opacity
  );
};
